==> 0.0.4.tar.gz: ios/Classes/OnechuanPlugin.m <==
#import "OnechuanPlugin.h"
#import <Contacts/Contacts.h>
#import <AddressBook/AddressBookDefines.h>
#import <AddressBook/ABRecord.h>


@implementation OnechuanPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"onechuan_plugin"
            binaryMessenger:[registrar messenger]];
  OnechuanPlugin* instance = [[OnechuanPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else if([@"getContacts" isEqualToString:call.method]){
      
//      result()
     [self getMyAddressbook:result];
      
  }
  
  
  else {
    result(FlutterMethodNotImplemented);
  }
}


- (void) getMyAddressbook:(FlutterResult)result{

    
    NSMutableDictionary *myDict = [[NSMutableDictionary alloc]init];
    
    // 获取指定的字段,并不是要获取所有字段，需要指定具体的字段
    NSArray *keysToFetch = @[CNContactGivenNameKey, CNContactFamilyNameKey, CNContactPhoneNumbersKey];
    CNContactFetchRequest *fetchRequest = [[CNContactFetchRequest alloc] initWithKeysToFetch:keysToFetch];
    CNContactStore *contactStore = [[CNContactStore alloc] init];
    
    NSMutableArray *mArray = [[NSMutableArray alloc] init];
    
    [contactStore enumerateContactsWithFetchRequest:fetchRequest error:nil usingBlock: ^(CNContact * _Nonnull contact, BOOL * _Nonnull stop) {
        NSLog(@"-------------------------------------------------------");
        
        NSString *givenName = contact.givenName;
        NSString *familyName = contact.familyName;
        NSLog(@"givenName=%@, familyName=%@", givenName, familyName);
        
        NSString *nameStr = [NSString stringWithFormat:@"%@%@",contact.familyName,contact.givenName];
        
        NSArray *phoneNumbers = contact.phoneNumbers;
         NSMutableDictionary *tempDic = [[NSMutableDictionary alloc]init];
        
        
        
        CNLabeledValue *labeledValue =[phoneNumbers objectAtIndex:0];

        tempDic[@"phone"] = labeledValue.value;
        tempDic[@"name"] = nameStr;
        
        
//        for (CNLabeledValue *labelValue in phoneNumbers) {
//            NSString *label = @"${labelValue.label}";
//            NSString *phoneNumber = @"${labelValue.value}";
//
//
//
//
//            [mArray addObject:tempDic];
//
//
//            NSLog(@"label=%@, phone=%@", label, phoneNumber);
//
//
//        }
        
       
        
//        return mArray;
        
        //[myDict setObject:phoneNumber forKey:nameStr];
        
        
        //    *stop = YES; // 停止循环，相当于break；
        
    }];
    
     result(mArray);
    
//    return mArray;
    
    
//    NSLog(@"mydict is ==== %@",myDict);

}


@end

==> 0.0.6.tar.gz: ios/Classes/OnechuanPlugin.m <==
#import "OnechuanPlugin.h"
#import <Contacts/Contacts.h>
#import <AddressBook/AddressBookDefines.h>
#import <AddressBook/ABRecord.h>


@implementation OnechuanPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"onechuan_plugin"
            binaryMessenger:[registrar messenger]];
  OnechuanPlugin* instance = [[OnechuanPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else if([@"getContacts" isEqualToString:call.method]){
      
//      result()
     [self getMyAddressbook:result];
      
  }
  
  
  else {
    result(FlutterMethodNotImplemented);
  }
}


- (void) getMyAddressbook:(FlutterResult)result{

    
    NSMutableDictionary *myDict = [[NSMutableDictionary alloc]init];
    
    // 获取指定的字段,并不是要获取所有字段，需要指定具体的字段
    NSArray *keysToFetch = @[CNContactGivenNameKey, CNContactFamilyNameKey, CNContactPhoneNumbersKey];
    CNContactFetchRequest *fetchRequest = [[CNContactFetchRequest alloc] initWithKeysToFetch:keysToFetch];
    CNContactStore *contactStore = [[CNContactStore alloc] init];
    
    NSMutableArray *mArray = [[NSMutableArray alloc] init];
    
    [contactStore enumerateContactsWithFetchRequest:fetchRequest error:nil usingBlock: ^(CNContact * _Nonnull contact, BOOL * _Nonnull stop) {
        NSLog(@"-------------------------------------------------------");
        
        NSString *givenName = contact.givenName;
        NSString *familyName = contact.familyName;
//        NSLog(@"givenName=%@, familyName=%@", givenName, familyName);
        
        NSString *nameStr = [NSString stringWithFormat:@"%@%@",contact.familyName,contact.givenName];
        
        NSArray *phoneNumbers = contact.phoneNumbers;
         NSMutableDictionary *tempDic = [[NSMutableDictionary alloc]init];
        
        
        
        CNLabeledValue *labeledValue =[phoneNumbers objectAtIndex:0];

        tempDic[@"phone"] = labeledValue.value;
        tempDic[@"name"] = nameStr;
        
         NSLog(@"name=%@, phone=%@", tempDic[@"name"] , tempDic[@"phone"]);
        
        
//        for (CNLabeledValue *labelValue in phoneNumbers) {
//            NSString *label = @"${labelValue.label}";
//            NSString *phoneNumber = @"${labelValue.value}";
//
//
//
//
//            [mArray addObject:tempDic];
//
//
//            NSLog(@"label=%@, phone=%@", label, phoneNumber);
//
//
//        }
        
       
        [mArray addObject:tempDic];
        
//        return mArray;
        
        //[myDict setObject:phoneNumber forKey:nameStr];
        
        
        //    *stop = YES; // 停止循环，相当于break；
        
    }];
    
     result(mArray);
    
//    return mArray;
    
    
//    NSLog(@"mydict is ==== %@",myDict);

}


@end
